'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _pathHelpers = require('../helpers/pathHelpers');

var _CheckboxInput = require('../../styles/cspace-input/CheckboxInput.css');

var _CheckboxInput2 = _interopRequireDefault(_CheckboxInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

const propTypes = {
  asText: _propTypes2.default.bool,
  className: _propTypes2.default.string,
  embedded: _propTypes2.default.bool,
  /* eslint-disable react/no-unused-prop-types */
  name: _propTypes2.default.string,
  parentPath: _pathHelpers.pathPropType,
  subpath: _pathHelpers.pathPropType,
  /* eslint-enable react/no-unused-prop-types */
  readOnly: _propTypes2.default.bool,
  transition: _propTypes2.default.object,
  trueLabel: _propTypes2.default.string,
  falseLabel: _propTypes2.default.string,
  indeterminateLabel: _propTypes2.default.string,
  value: _propTypes2.default.any,
  onCommit: _propTypes2.default.func,
  onClick: _propTypes2.default.func
};

const defaultProps = {
  transition: {
    null: true,
    true: false,
    false: true
  },
  trueLabel: 'yes',
  falseLabel: 'no',
  indeterminateLabel: 'indeterminate'
};

class CheckboxInput extends _react.Component {
  constructor() {
    super();

    this.handleChange = this.handleChange.bind(this);
  }

  handleChange() {
    var _props = this.props;
    const transition = _props.transition,
          value = _props.value,
          onCommit = _props.onCommit;


    if (onCommit) {
      const normalizedValue = typeof value === 'undefined' ? null : value;
      const newValue = transition[normalizedValue];

      onCommit((0, _pathHelpers.getPath)(this.props), newValue);
    }
  }

  render() {
    var _props2 = this.props;

    const asText = _props2.asText,
          className = _props2.className,
          embedded = _props2.embedded,
          readOnly = _props2.readOnly,
          value = _props2.value,
          trueLabel = _props2.trueLabel,
          falseLabel = _props2.falseLabel,
          indeterminateLabel = _props2.indeterminateLabel,
          onClick = _props2.onClick,
          name = _props2.name,
          parentPath = _props2.parentPath,
          subpath = _props2.subpath,
          transition = _props2.transition,
          onCommit = _props2.onCommit,
          remainingProps = _objectWithoutProperties(_props2, ['asText', 'className', 'embedded', 'readOnly', 'value', 'trueLabel', 'falseLabel', 'indeterminateLabel', 'onClick', 'name', 'parentPath', 'subpath', 'transition', 'onCommit']);

    let checked;
    let textValue;

    let classes = (0, _classnames2.default)({
      [_CheckboxInput2.default.readOnly]: readOnly,
      [_CheckboxInput2.default.normal]: !readOnly,
      [_CheckboxInput2.default.embedded]: embedded
    }, className);

    if (value === true) {
      checked = true;
      textValue = trueLabel;
    } else if (value === false) {
      checked = false;
      textValue = falseLabel;
    } else {
      checked = false;
      textValue = indeterminateLabel;
      classes = (0, _classnames2.default)(classes, _CheckboxInput2.default.indeterminate);
    }

    if (asText) {
      return _react2.default.createElement(
        'div',
        { className: classes },
        textValue
      );
    }

    // FIXME: Don't break these lint rules.

    /* eslint-disable jsx-a11y/label-has-for, jsx-a11y/no-static-element-interactions */
    return _react2.default.createElement(
      'label',
      { className: classes, onClick: onClick },
      _react2.default.createElement('input', _extends({
        checked: checked,
        disabled: readOnly,
        name: name,
        type: 'checkbox',
        onChange: this.handleChange
      }, remainingProps)),
      _react2.default.createElement('span', null)
    );
    /* eslint-enable jsx-a11y/label-has-for, jsx-a11y/no-static-element-interactions */
  }
}

exports.default = CheckboxInput;
CheckboxInput.propTypes = propTypes;
CheckboxInput.defaultProps = defaultProps;